@@ -8,8 +8,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-py-autopep8
 ;; Keywords: convenience
-;; Package-Version: 20250913.2251
-;; Package-Revision: a72b83e04dbb
+;; Package-Version: 20251106.1057
+;; Package-Revision: bd27cd34ab17
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -159,7 +159,7 @@ Useful for fast operation, especially for automated conversion or tests."
 When RANGE is non-nil it's used as the range to format.
 Return non-nil when a the buffer was modified."
   (declare (important-return-value t))
-  (when (not (executable-find py-autopep8-command))
+  (unless (executable-find py-autopep8-command)
     (user-error "py-autopep8: %s command not found" py-autopep8-command))
 
   ;; Set the default coding for the temporary buffers.
